@@ -79,7 +79,13 @@ pub fn main() -> io::Result<()> {
               if let Cirru::List(ys) = line {
                 match (ys.get(0), ys.get(1)) {
                   (Some(Cirru::Leaf(x0)), Some(Cirru::Leaf(x1))) => {
-                    if x0 == "def" || x0 == "defn" || x0 == "defmacro" || x0 == "defatom" || x0 == "defrecord" {
+                    if x0 == "def"
+                      || x0 == "defn"
+                      || x0 == "defmacro"
+                      || x0 == "defatom"
+                      || x0 == "defrecord"
+                      || x0.starts_with("def")
+                    {
                       defs.insert(Edn::Str(x1.to_owned()), Edn::Quote(line.to_owned()));
                     } else {
                       return Err(io_err(format!("invalid def op: {}", x0)));
