@@ -433,7 +433,7 @@ fn gen_call_code(
         },
         "js-await" => match body.get(0) {
           Some(body) => Ok(format!(
-            "await {}",
+            "(await {})",
             to_js_code(&body, ns, local_defs, file_imports, &None)?,
           )),
           None => Err(format!("`new` expected constructor, got nothing, {}", xs)),
@@ -469,7 +469,7 @@ fn gen_call_code(
               )),
               None => Err(format!("property accessor takes only 1 argument, {:?}", xs)),
             }
-          } else {
+          } else if matches_js_var(name) {
             match body.get(0) {
               Some(obj) => Ok(format!(
                 "{}{}.{}",
@@ -479,6 +479,17 @@ fn gen_call_code(
               )),
               None => Err(format!("property accessor takes only 1 argument, {:?}", xs)),
             }
+          } else {
+            // includes characters that need to be escaped
+            match body.get(0) {
+              Some(obj) => Ok(format!(
+                "{}{}[\"{}\"]",
+                return_code,
+                to_js_code(&obj, ns, local_defs, file_imports, &None)?,
+                name,
+              )),
+              None => Err(format!("property accessor takes only 1 argument, {:?}", xs)),
+            }
           }
         }
         _ if s.starts_with(".!") => {
